# fabcohort
A small demo library for a fab_cohort about cohort analysis

### Installation
```
pip install fabcohort
```

### Get started
How to do cohort analysis with this lib:

```Python
from fab_cohort import Cohort

# Instantiate a Cohort object
cohort = Cohort()

# Call the count_cohort method
result = cohort.count_cohort(df)

```